'''
    Copyright (C) 2019 Moxa Inc. All rights reserved.
    SPDX-License-Identifier: Apache-2.0

    UART Python Sample Application

    Date          Author            Comment
    2019-02-11    William Chang     Created it.
'''

##
# @file uart.py
# @copyright 2019 Moxa Inc. All rights reserved.
# @date 2019-02-11
# @author William Chang
# @version V1.0
# @brief <b>UART Sample</b>
# @details <b>Library:</b><br>
# @link UART UART APIs @endlink
# @include uart.py

from ioThinx_4530 import ioThinx_4530_API
import argparse
import os

BUF_LEN = 4096
UART_MODE_RS232 = 0
UART_PORT_1 = 0


def main():
    parser = argparse.ArgumentParser(description="Miscellaneous sample program.")
    parser.add_argument("-b", "--baudrate", dest="uart_baudrate", type=int, default=115200)
    parser.add_argument("-p", "--port", dest="uart_port", type=int, default=UART_PORT_1)
    parser.add_argument("-m", "--mode", dest="uart_mode", type=int, default=UART_MODE_RS232)
    args = parser.parse_args()

    uart_slot = 0
    uart_port = args.uart_port
    uart_mode = args.uart_mode
    uart_baudrate = args.uart_baudrate
    print("UART slot = {}".format(uart_slot))
    print("UART port = {}".format(uart_port))
    print("UART mode = {}".format(uart_mode))
    print("UART baudrate = {}".format(uart_baudrate))

    device = ioThinx_4530_API.ioThinx_4530_API()
    fd = device.ioThinx_Uart_Open(uart_slot, uart_port, uart_mode, uart_baudrate)
    print("fd = {}".format(fd))
    print("Start UART echo.")

    while True:
        buf = os.read(fd, BUF_LEN)
        print(len(buf))
        print(buf)
        if len(buf) > 0:
            os.write(fd, buf)
            if 'quit' in buf.decode():
                break

    print("Stop UART echo.")
    os.close(fd)


if __name__ == '__main__':
    main()
